PageSourceSearch

https://www.fkh.no/maer-enn-tri-poeng

html fkh.no collected 2026-10-02 19:42:11 UTC 73,213 bytes, 1,279 lines download raw bytes

1<!DOCTYPE html>
2<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="nb" lang="nb" prefix="og:https://ogp.me/ns">
3<head>
3<script id="Cookiebot" src="https://consent.cookiebot.com/uc.js" data-cbid="6ec37fe1-0bdc-4bd0-9faf-c539a2f10ab0" data-blockingmode="auto" type="text/javascript"></script>
3<link rel="preconnect" href="https://cdn.usefathom.com">
4    <meta charset="utf-8" />
5    <meta name="viewport" content="width=device-width, initial-scale=1.0">
6    
7    <meta http-equiv="content-language" content="nb-no">
8
9    <title>Mær enn tri poeng / fkh</title>
10    <link rel="home" href="https://www.fkh.no/" />
11    <!-- Gotham XNarrow -->
12
13    <link rel="stylesheet" type="text/css" href="https://cloud.typography.com/6417356/6804032/css/fonts.css" />
14    <link rel="manifest" href="/manifest.json">
15
16    <!--<link rel="stylesheet" type="text/css" href="/css/.css"/>-->
17    <link rel="stylesheet" type="text/css" href="/_/asset/no.seeds.app.football:0000019ff1669df0/compiled/css/fkh.css"/>
18    <link rel="stylesheet" type="text/css" href="/_/service/no.seeds.app.football/asset/0000019ff1669df0/compiled/css/seeds.css"/>
19    <link rel="stylesheet" type="text/css" href="/_/service/no.seeds.app.football/asset/0000019ff1669df0/css/jquery-ui.css"/>
20    
20<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/js/jquery.js"></script>
20
21    
21<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/js/jquery-ui.js"></script>
21
22    
22<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/js/jquery.cookie.js"></script>
22
23
24    
24<script src="https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.29.1/moment.min.js" integrity="sha512-qTXRIMyZIFb8iQcfjXWCO8+M5Tbc38Qi5WzdPOYZHIlZpzBHG3L3by84BBBOiRGiEb7KKtAOAs5qYdUiZiQNNQ==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
24
25    
25<script src="https://cdnjs.cloudflare.com/ajax/libs/moment-timezone/0.5.33/moment-timezone-with-data.min.js" integrity="sha512-rjmacQUGnwQ4OAAt3MoAmWDQIuswESNZwYcKC8nmdCIxAVkRC/Lk2ta2CWGgCZyS+FfBWPgaO01LvgwU/BX50Q==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
25
26
27    
27<script async src="https://securepubads.g.doubleclick.net/tag/js/gpt.js"></script>
27
28
29    
29<script type="text/javascript">
30        var redirectSession = sessionStorage.getItem('redirectSession');
31        var urlParams = new URLSearchParams(window.location.search);
32
33        if (redirectSession) {
34            sessionStorage.removeItem('redirectSession');
35            window.location.href = redirectSession;
36        }
37    </script>
37
38    <!-- ------------ smartApp Banner ------------------------------------- -->
39    
40    <!-- ------------------------------------------------------------------ -->
41
42	<!-- Begin ContainR -->
43<script type='application/javascript'>!function(n,t,a,i){n.mpfContainr||(n.mpfContainr=function(){a.push(arguments)},mpfContainr.q=a,(i=t.createElement('script')).type='application/javascript',i.async=!0,i.src='//cdn.mookie1.com/containr.js',t.head.appendChild(i))}(window,document,[]);
44mpfContainr('V2_680863',{'host': 'no-gmtdmp.mookie1.com', 'tagType': 'activity','src.rand' : '1790970130'});
45</script>
45
46<noscript>
47<iframe src='//no-gmtdmp.mookie1.com/t/v2?tagid=V2_680863&isNoScript&&src.rand=1790970130' height='0' width='0' style='display:none;visibility:hidden'></iframe>
48</noscript>
49<!-- End ContainR -->
50
51<!-- Begin ContainR -->
52<script type='application/javascript'>!function(n,t,a,i){n.mpfContainr||(n.mpfContainr=function(){a.push(arguments)},mpfContainr.q=a,(i=t.createElement('script')).type='application/javascript',i.async=!0,i.src='//cdn.mookie1.com/containr.js',t.head.appendChild(i))}(window,document,[]);
53mpfContainr('V2_680975',{'host': 'no-gmtdmp.mookie1.com', 'tagType': 'activity','src.rand' : '1790970130'});
54</script>
54
55<noscript>
56<iframe src='//no-gmtdmp.mookie1.com/t/v2?tagid=V2_680975&isNoScript&&src.rand=1790970130' height='0' width='0' style='display:none;visibility:hidden'></iframe>
57</noscript>
58<!-- End ContainR -->
59
60<style>
61#CybotCookiebotDialog a,
62#CybotCookiebotDialog a:hover,
63#CybotCookiebotDialog a:after
64{	
65  background-color: transparent;
66  border-bottom: none !important;
67}
68
69#CybotCookiebotDialog img{
70	width: auto !important;
71}
72</style><style>
73                        .navigationBar__items--item > .active > svg > path {
74                            stroke: #9c9d9e;
75                        }
76                    </style><link href="https://www.fkh.no/maer-enn-tri-poeng" rel="canonical" />
77	
78	<meta name="description" />
79	<meta property="og:title" content="Mær enn tri poeng" />
80	<meta property="og:description" />
81	<meta property="og:site_name" content="fkh" />
82	<meta property="og:url" content="https://www.fkh.no/maer-enn-tri-poeng" />
83	<meta property="og:type" content="article" />
84	<meta property="og:locale" content="nb_NO" />
85
86	
87		<meta property="og:image" content="https://www.fkh.no/_/asset/no.seeds.app.football:0000019ff1669df0/img/logo/fkh/logo.png" />
88		<meta property="og:image:width" content="1200" />
89		<meta property="og:image:height" content="630" />
90	
91	
92
93
94	<link rel="apple-touch-icon" sizes="57x57" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-57x57.png">
95	<link rel="apple-touch-icon" sizes="60x60" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-60x60.png">
96	<link rel="apple-touch-icon" sizes="72x72" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-72x72.png">
97	<link rel="apple-touch-icon" sizes="76x76" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-76x76.png">
98	<link rel="apple-touch-icon" sizes="114x114" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-114x114.png">
99	<link rel="apple-touch-icon" sizes="120x120" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-120x120.png">
100	<link rel="apple-touch-icon" sizes="144x144" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-144x144.png">
101	<link rel="apple-touch-icon" sizes="152x152" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-152x152.png">
102	<link rel="apple-touch-icon" sizes="180x180" href="/_/asset/no.seeds.app.football/img/logo/fkh/apple-icon-180x180.png">
103	<link rel="icon" type="image/png" sizes="192x192"  href="/_/asset/no.seeds.app.football/img/logo/fkh/android-icon-192x192.png">
104	<link rel="icon" type="image/png" sizes="32x32" href="/_/asset/no.seeds.app.football/img/logo/fkh/favicon-32x32.png">
105	<link rel="icon" type="image/png" sizes="96x96" href="/_/asset/no.seeds.app.football/img/logo/fkh/favicon-96x96.png">
106	<link rel="icon" type="image/png" sizes="16x16" href="/_/asset/no.seeds.app.football/img/logo/fkh/favicon-16x16.png">
107
108
109
110    <meta name="apple-mobile-web-app-status-bar-style" content="#ffffff">
111    <meta name="apple-mobile-web-app-title" content="Haugesund">
112    <meta name="apple-mobile-web-app-capable" content="yes">
113
114	<link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/055cf437-70cd-49b8-a4ea-0918a9dcd552:d53f47bea95445f82fe02fb0a27c8a4d5f62e744/-1-1/apple-icon-640x1136" media="(device-width: 320px) and (device-height: 568px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/e4d51405-ebf1-4ae5-bafb-c78be6907d80:4bc9702bbc75a753d4057f47522db3ea7837fe77/-1-1/apple-icon-1136x640" media="(device-width: 320px) and (device-height: 568px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/47f94389-1a04-450b-8057-525d44cf3edb:b7034c13a97a0c83e6c1c4ff85a963205ca2c0df/-1-1/apple-icon-750x1334" media="(device-width: 375px) and (device-height: 667px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/1fe0acc8-db5d-48d0-8a77-90b18d9f0167:13d86b36b4325d29cb70683678e654554e6306a9/-1-1/apple-icon-1334x750" media="(device-width: 375px) and (device-height: 667px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/5b203d40-e636-4f8e-b34b-5f84db02af72:52c27bd28705248c32d661d53b0dd2190b
1140b3474/-1-1/apple-icon-1242x2208" media="(device-width: 621px) and (device-height: 1104px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/67c328fc-749c-457c-8d3f-b53e6db72dad:274e0373c01a2feaa72050738155caea806ed890/-1-1/apple-icon-2208x1242" media="(device-width: 621px) and (device-height: 1104px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/d461d5f2-3cd6-4940-90fa-47fe0db0fdc7:a2beb9c472d901e09123bc2bd47767a8b2610116/-1-1/apple-icon-1125x2436" media="(device-width: 375px) and (device-height: 812px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/dc844473-955e-49b4-a34a-a986971f40d3:a8394c5d749522bf8a0c63954120a7488ebbe498/-1-1/apple-icon-2436x1125" media="(device-width: 375px) and (device-height: 812px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/8825166f-5c5a-49c8-979b-c24c26d312fd:65311c54c6bca2fcf59d62da8111d429c9c2aabd/-1-1/apple-icon-828x1792" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/658ed55e-7669-4451-9b90-de1ed40767d3:26e7c5eae8c2470e8df6af3a31fadd7edef042d8/-1-1/apple-icon-1792x828" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/11bbd05c-6d89-4a57-a2ba-9c3704f1ae1c:210e50cce1031c958acad19eaeefb7b66a69eeec/-1-1/apple-icon-1242x2688" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 3) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/6b6e3e29-10eb-41b2-9c36-2a6e4d9626c9:257d6b2fa748da91af2a8cde49e573f23c056499/-1-1/apple-icon-2688x1242" media="(device-width: 414px) and (device-height: 896px) and (-webkit-device-pixel-ratio: 3) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/d79cd893-bc91-4148-9889-f93bd1dc26b8:287787a7cd59c4f62a2075b853ef16892a4759ed/-1-1/apple-icon-1536x2048" media="(device-width: 768px) and (device-height: 1024px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/ad2aa662-ea42-492a-93aa-003ab00e185f:96c857546f9f3d1c81daae3502c831d6809d1dbe/-1-1/apple-icon-2048x1536" media="(device-width: 768px) and (device-height: 1024px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/4e4d5b30-14d5-4558-9b85-9d6541cec710:edfa352f1597111c69ca3513ffb50f500bf9a99d/-1-1/apple-icon-1668x2224" media="(device-width: 834px) and (device-height: 1112px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/7719f89f-e061-4331-8412-5fd31ca79fbe:d1bffd6843456399b23007bafbbda681b4e21b6b/-1-1/apple-icon-2224x1668" media="(device-width: 834px) and (device-height: 1112px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/78ea4da8-925c-40cd-a861-589944609b37:97e195895f6c2a2af7b61ba9a20d602d5c559f1d/-1-1/apple-icon-1668x2388" media="(device-width: 834px) and (device-height: 1194px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/879a7444-f8dc-4e5c-b1e4-d9e9a3e0d141:a60b4b27ad6831ab021bd711c9329b53844a6b1f/-1-1/apple-icon-2388x1668" media="(device-width: 834px) and (device-height: 1194px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/4d83df6f-1598-4d7a-9631-158afd7ee2ba:ad7e08f70c402cc029e2413879ba65d64b0cda72/-1-1/apple-icon-2048x2732" media="(device-width: 1024px) and (device-height: 1366px) and (-webkit-device-pixel-ratio: 2) and (orientation:portrait)"><link rel="apple-touch-startup-image" href="/maer-enn-tri-poeng/_/image/160d45eb-62f7-47b1-8fcd-13d6b002ace6:14535669b2500ee373d14c775c59795772483448/-1-1/apple-icon-2732x2048" media="(device-width: 1024px) and (device-height: 1366px) and (-webkit-device-pixel-ratio: 2) and (orientation:landscape)">
115
116	<meta name="msapplication-TileColor" content="#ffffff">
117	<meta name="msapplication-TileImage" content="/_/asset/no.seeds.app.football/img/logo/fkh/ms-icon-144x144.png">
118	<meta name="theme-color" content="#ffffff"><!-- Google Tag Manager -->
118<script>dataLayer = [];</script>
118<script>
vendor: 317 bytes, line 118
118(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src='//www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);})(window,document,'script','dataLayer','
118GTM-WL4Z9Q2
vendor: 3 bytes, line 118
118');
118</script>
118<!-- End Google Tag Manager -->
118<script src="https://cdn.usefathom.com/script.js" data-site="SYMVVHIL"  defer></script>
118<!-- Facebook Pixel Code -->
119<script>
120!function(f,b,e,v,n,t,s){if(f.fbq)return;n=f.fbq=function(){n.callMethod?
121n.callMethod.apply(n,arguments):n.queue.push(arguments)};if(!f._fbq)f._fbq=n;
122n.push=n;n.loaded=!0;n.version='2.0';n.queue=[];t=b.createElement(e);t.async=!0;
123t.src=v;s=b.getElementsByTagName(e)[0];s.parentNode.insertBefore(t,s)}(window,
124document,'script','//connect.facebook.net/en_US/fbevents.js');
125// Insert Your Facebook Pixel ID below.
126fbq('init', "803479659768440");
127fbq('track', 'PageView');
128</script>
128
129<!-- Insert Your Facebook Pixel ID below. -->
130<noscript><img height="1" width="1" style="display:none"
131src="https://www.facebook.com/tr?id=803479659768440&amp;ev=PageView&amp;noscript=1"
132/></noscript>
133<!-- End Facebook Pixel Code --><link rel="alternate" type="application/rss+xml" title="Nyheter" href="https://www.fkh.no/rss-nyheter" /></head>
134
135<body data-ng-controller="body" data-ng-class="{'menu-is-visible': showMenu}" class="body__fkh"><!-- Google Tag Manager (noscript) -->
vendor: 61 bytes, line 135
135<noscript><iframe src="//www.googletagmanager.com/ns.html?id=
135GTM-WL4Z9Q2
vendor: 82 bytes, line 135
135" height="0" width="0" style="display:none;visibility:hidden"></iframe></noscript>
135<!-- End Google Tag Manager (noscript) -->
136
137
138<script>
139    const splashPwa = $('.splash--pwa');
140    const isRunningStandalone = (window.matchMedia('(display-mode: standalone)').matches);
141
142    const shouldShowFakeSplash = sessionStorage.getItem('splash_pwa') !== 'displayed' && isRunningStandalone;
143
144    if (shouldShowFakeSplash){
145        splashPwa.show();
146        $('.splash--pwa img').load(function () {
147            $('.splash--pwa img').show();
148        });
149    }
150
151    document.addEventListener('DOMContentLoaded', onDomLoaded);
152
153    function onDomLoaded(){
154        if (shouldShowFakeSplash){
155            setTimeout(function(){
156                splashPwa.addClass('splash--display--none');
157                sessionStorage.setItem('splash_pwa', 'displayed');
158            }, 3000);
159        }
160    };
161</script>
161
162
163
164<svg style="display:none">
165    <symbol id="arrow" viewBox="0 0 46 33">
166        <polygon points="0 18.355 41.662 18.355 41.662 14.355 0 14.355"></polygon>
167        <polygon points="28.408 32.715 25.68 29.785 40.127 16.359 25.68 2.93 28.408 0 46 16.359"></polygon>
168    </symbol>
169
170    <symbol id="arrow-right" viewBox="0 0 24 24">
171        <polygon points="7.875,0 4.125,3.75 12.375,12 4.125,20.25 7.875,24 19.875,12 "></polygon>
172    </symbol>
173
174    <symbol id="arrow-left" viewBox="0 0 24 24">
175        <polygon points="16.125,24 19.875,20.25 11.625,12 19.875,3.75 16.125,0 4.125,12 "></polygon>
176    </symbol>
177</svg>
178
179<div class="bg-overflow"></div>
180
181
182    
183        <header class="header" ng-class="{'header--show-menu': showMenu, 'header--show-search': showSearch}">
184	
185	<div class="header__global">
186		<div class="container">
187			<nav class="header__global__nav" aria-label="Meny">
188				<a class="header__global__nav__item" href="https://www.fkh.no/nyheter/presseakkreditering">
189					Presse
190				</a><a class="header__global__nav__item header__global__nav__item--active" href="https://www.fkh.no/maer-enn-tri-poeng">
191					Mær Enn Tri Poeng
192				</a><a class="header__global__nav__item" href="https://www.fkh.no/samarbeidspartnere">
193					Partnere
194				</a><a class="header__global__nav__item" href="https://www.fkh.no/nettbutikk">
195					Nettbutikk
196				</a><a class="header__global__nav__item" href="https://www.fkh.no/nyheter/jenteloftet">
197					Jenteløftet
198				</a><a class="header__global__nav__item" href="https://www.fkh.no/medlem">
199					Bli medlem
200				</a><a class="header__global__nav__item" href="https://www.fkh.no/feature/kraftakademiet-ffo">
201					Fotballfritidsordning (FFO)
202				</a>
203				<!-- Login/Logout/Minside links -->
204				<input id="idrettens-link-service" type="hidden" value="https://www.fkh.no/maer-enn-tri-poeng/_/service/no.seeds.app.football/get-login-links">
205				<a id="login-link" class="modal__login modal-open" href="javascript:void(0)" hidden>
206                    <svg stroke="white" width="24" height="20" viewBox="0 0 24 20" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="loginTitle">
207                        <title id="loginTitle"></title>
208                        <path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke-width="1.5" stroke-miterlimit="10"/>
209                        <path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
210                    </svg>
211                </a>
212                <a id="minside-link" href="javascript:void(0)" hidden>
213                    <svg stroke="white" width="24" height="20" viewBox="0 0 24 20" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="minsideTitle">
214                        <title id="minsideTitle"></title>
215                        <path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke-width="1.5" stroke-miterlimit="10"/>
216                        <path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
217                    </svg>
218                </a>
219                <a id="logout-link" class="logout" href="javascript:void(0)" hidden>
220                    <svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
221 viewBox="0 0 384.971 384.971" style="enable-background:new 0 0 384.971 384.971;" xml:space="preserve" aria-labelledby="logoutTitle">
222                        <title id="logoutTitle"></title>
223                        <g>
224                            <g id="Sign_Out">
225                                <path d="M180.455,360.91H24.061V24.061h156.394c6.641,0,12.03-5.39,12.03-12.03s-5.39-12.03-12.03-12.03H12.03
226                                    C5.39,0.001,0,5.39,0,12.031V372.94c0,6.641,5.39,12.03,12.03,12.03h168.424c6.641,0,12.03-5.39,12.03-12.03
227                                    C192.485,366.299,187.095,360.91,180.455,360.91z"/>
228                                <path d="M381.481,184.088l-83.009-84.2c-4.704-4.752-12.319-4.74-17.011,0c-4.704,4.74-4.704,12.439,0,17.179l62.558,63.46H96.279
229                                    c-6.641,0-12.03,5.438-12.03,12.151c0,6.713,5.39,12.151,12.03,12.151h247.74l-62.558,63.46c-4.704,4.752-4.704,12.439,0,17.179
230                                    c4.704,4.752,12.319,4.752,17.011,0l82.997-84.2C386.113,196.588,386.161,188.756,381.481,184.088z"/>
231                            </g>
232                        </g>
233                    </svg>
234                </a>
235				<a class="open-push-notification-modal header__global__nav__item" href="javascript:void(0)" style="display: none;">
236                    <svg stroke="white" width="24px" height="20px" viewBox="0 0 611.999 611.999" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
237                        <title id="renewPushTitle"></title>
238                        <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
239                            C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
240                            c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
241                            h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
242                            c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
243                            C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
244                            c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
245                            c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
246                            M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
247                            c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
248                            c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"/>
249                        <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
250                            c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
251                            C323.259,126.96,315.532,119.235,306.001,119.235z"/>
252                    </svg>
253                </a>
254			</nav>
255		</div>
256	</div>
257	<div class="header__team">
258		<div class="container">
259			<a href="https://www.fkh.no/" class="header__team__brand">
260				<div class="header__team__brand__container">
261					<div class="header__team__brand__div">
262						<img class="header__team__brand__img header__team__brand__img--fkh" src="https://www.fkh.no/maer-enn-tri-poeng/_/image/dff142f0-041c-49cd-bac2-f5311254efa0:6064425925da495c54dfee7cbbcde8defc3b9897/wide-72-72/Logo%20550%202.svg" role="img" alt="Forsiden på fkh.no"/>
263					</div>
264					<div class="header__team__brand__titles">
265						
266						
267					</div>
268				</div>
269			</a>
270		</div>
271	</div>
272	<div class="header__bar">
273		<div class="container">
274			<a class="header__bar__brand" href="https://www.fkh.no/">
275				<img class="header__bar__brand__img" src="https://www.fkh.no/maer-enn-tri-poeng/_/image/dff142f0-041c-49cd-bac2-f5311254efa0:6064425925da495c54dfee7cbbcde8defc3b9897/wide-72-72/Logo%20550%202.svg" title="Til forsiden på https://www.fkh.no/" alt="Logo" />
276			</a>
277
278			<div class="header__menu">
279				<nav class="header__menu__nav" aria-label="Hovedmeny">
280					<!-- Set modifier class "header__menu__nav__item--active" on active menu elements -->
281					
282						
283							<a class="header__menu__nav__item" href="https://www.fkh.no/nyheter">
284								<span class="header__menu__nav__item__title">Nyheter</span>
285							</a>
286						
287					
288					
289						
290							<a class="header__menu__nav__item" href="https://www.fkh.no/lag">
291								<span class="header__menu__nav__item__title">Lagene</span>
292							</a>
293						
294					
295					
296						
297							<a class="header__menu__nav__item" href="https://www.fkh.no/terminl
297iste">
298								<span class="header__menu__nav__item__title">Terminliste</span>
299							</a>
300						
301					
302					
303						
304							<a class="header__menu__nav__item" href="https://www.fkh.no/resultater">
305								<span class="header__menu__nav__item__title">Resultater</span>
306							</a>
307						
308					
309					
310						
311							<a class="header__menu__nav__item" href="https://www.fkh.no/billetter">
312								<span class="header__menu__nav__item__title">Billetter &amp; Sesongkort</span>
313							</a>
314						
315					
316					
317						
318							<a class="header__menu__nav__item" href="https://www.fkh.no/nyheter/fkh-akademiet/kraftakademiet">
319								<span class="header__menu__nav__item__title">Kraftakademiet</span>
320							</a>
321						
322					
323					
324						
325							<a class="header__menu__nav__item" href="https://www.fkh.no/om-klubben">
326								<span class="header__menu__nav__item__title">Om Klubben</span>
327							</a>
328						
329					
330					
331				</nav>
332				<div class="header__menu__sponsor">
333					<a class="header__menu__sponsor__item" href="https://fkh.no" target="_blank">
334						<img src="https://www.fkh.no/maer-enn-tri-poeng/_/image/03be7190-20c7-43c3-a886-a02c356e21e6:bd76f8de58bca996d1b7f9892e4894d9f00ac662/height-100/Miljoefyrtaarn-sertifisert-REV.png" alt="Miljøfyrtårn">
335					</a>
336
337				</div>
338			</div>
339
340			<div class="header__bar__nav">
341				<button class="header__bar__nav__item header__bar__nav__item--menu" type="button" ng-click="toggleMenu(); showSearch = false;">
342					<span data-ng-if="!showMenu">
343						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
344<path d="M22.4511719,6H1.5C0.671875,6,0,5.3286133,0,4.5S0.671875,3,1.5,3h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
345	S23.2792969,6,22.4511719,6z"></path>
346<path d="M22.4511719,13.5H1.5C0.671875,13.5,0,12.8286133,0,12s0.671875-1.5,1.5-1.5h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
347	S23.2792969,13.5,22.4511719,13.5z"></path>
348<path d="M22.4511719,21H1.5C0.671875,21,0,20.3286133,0,19.5S0.671875,18,1.5,18h20.9511719c0.828125,0,1.5,0.6713867,1.5,1.5
349	S23.2792969,21,22.4511719,21z"></path>
350</svg></span>
351						Meny
352					</span>
353					<span data-ng-if="showMenu" class="ng-cloak">
354						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
355<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
356	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
357	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
358	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
359	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
360	"></path>
361</svg></span>
362						Lukk meny
363					</span>
364				</button>
365				<button class="header__bar__nav__item header__bar__nav__item--search" type="button" ng-click="toggleSearch(); queryReset = true; showMenu = false;">
366					<span data-ng-if="!showSearch">
367						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
368<path id="search" d="M17.7191334,15.5738506c2.5573559-3.8850498,2.4550629-9.4922314-0.961565-12.9057446
369	c-4.037859-3.754458-10.3484344-3.5178807-14.095067,0.5284102c-3.5613694,3.8462107-3.5484405,9.7972965,0.0296073,13.6279316
370	c3.4166281,3.4135132,8.9916639,3.4852676,12.858386,0.9020691L21.8313618,24L24,21.8268318L17.7191334,15.5738506z
371	 M4.3185873,15.2048225C1.3234186,12.2014732,1.324975,7.3336434,4.3220639,4.3322186s7.854773-2.9998651,10.8499432,0.0034833
372	c2.9938126,3.0019879,2.9938126,7.8671322,0,10.8691206c-2.9951696,3.0033493-7.8528538,3.0049095-10.8499432,0.0034838
373	C4.3209047,15.2071447,4.319746,15.2059841,4.3185873,15.2048225z"></path>
374</svg></span>
375						Søk
376					</span>
377					<span data-ng-if="showSearch" class="ng-cloak">
378						<span class="header__bar__nav__item__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
379<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
380	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
381	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
382	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
383	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
384	"></path>
385</svg></span>
386						Lukk søk
387					</span>
388				</button>
389			</div>
390		</div>
391		<div class="header__search">
392			<div class="container">
393				<div class="search-field__area o-no-margin">
394					<form action="https://www.fkh.no/sok" method="get">
395
396						<input id="search-field__input_header" class="search-field__input" aria-label="Søk" type="text" autocomplete="off" data-ng-model="query"
397						    name="text" data-bind-focus="queryReset" data-ng-focus="queryReset == true" data-e
397sc-key="query = ''" placeholder="Søk i www.fkh.no" maxlength="128">
398						
399						<span class="search-field__area__icon" data-ng-show="query.length > 0" data-ng-click="query = ''; queryReset = true;">
400							<span><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
401<path d="M14.0969238,12.0000114l6.3466797-6.3466797c0.5855713-0.5855713,0.5859375-1.5354004,0-2.1213379
402	s-1.5357666-0.5855713-2.1213379,0l-6.3466797,6.3466797L5.6289062,3.5319939c-0.5855713-0.5855713-1.5354004-0.5859375-2.1213379,0
403	s-0.5855713,1.5357666,0,2.1213379l6.3466797,6.3466797l-6.3466797,6.3466797c-0.5855713,0.5855713-0.5859375,1.5354004,0,2.1213379
404	c0.5859375,0.5858765,1.5357666,0.5855713,2.1213379,0l6.3466797-6.3466797l6.3466797,6.3466797
405	c0.5855713,0.5855713,1.5354004,0.5858765,2.1213379,0c0.5859375-0.5859375,0.5855713-1.5357666,0-2.1213379L14.0969238,12.0000114z
406	"></path>
407</svg></span>
408						</span>
409						<span class="search-field__area__icon" data-ng-hide="query.length > 0">
410							<span><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
411<path id="search" d="M17.7191334,15.5738506c2.5573559-3.8850498,2.4550629-9.4922314-0.961565-12.9057446
412	c-4.037859-3.754458-10.3484344-3.5178807-14.095067,0.5284102c-3.5613694,3.8462107-3.5484405,9.7972965,0.0296073,13.6279316
413	c3.4166281,3.4135132,8.9916639,3.4852676,12.858386,0.9020691L21.8313618,24L24,21.8268318L17.7191334,15.5738506z
414	 M4.3185873,15.2048225C1.3234186,12.2014732,1.324975,7.3336434,4.3220639,4.3322186s7.854773-2.9998651,10.8499432,0.0034833
415	c2.9938126,3.0019879,2.9938126,7.8671322,0,10.8691206c-2.9951696,3.0033493-7.8528538,3.0049095-10.8499432,0.0034838
416	C4.3209047,15.2071447,4.319746,15.2059841,4.3185873,15.2048225z"></path>
417</svg></span>
418						</span>
419					</form>
420				</div>
421			</div>
422		</div>
423	</div>
424</header>
425
426    
427    
428
429
430<main class="body" data-portal-region="main">
431    
432    
433        
434            <!-- HYPE-MODULE INIT -->
435
436	<div data-portal-component-type="part" class="history history--hype  history--volume-medium">
437		<a class="history__outer" href="https://www.fkh.no/maer-enn-tri-poeng/articles/samfunnsprosjekter">
438			<div class="history__pattern">
439				<div class="history__pattern__back"></div>
440				<div class="history__pattern__front"></div>
441				<div class="history__figure">
442					<figure>
443						
444						
445							<picture>
446								<source media="(max-width:500px)" srcset="/maer-enn-tri-poeng/_/image/eeea5b0e-1543-4892-812c-826ef5698f1c:5a6293904e37b60369673e84da8499aa9d9b7d05/wide-500-281/Maer-enn-tri-poeng-drakt-ill.jpg 1x, /maer-enn-tri-poeng/_/image/eeea5b0e-1543-4892-812c-826ef5698f1c:5a6293904e37b60369673e84da8499aa9d9b7d05/wide-1000-562/Maer-enn-tri-poeng-drakt-ill.jpg 2x">
447								<source media="(max-width:840px)" srcset="/maer-enn-tri-poeng/_/image/eeea5b0e-1543-4892-812c-826ef5698f1c:5a6293904e37b60369673e84da8499aa9d9b7d05/wide-840-472/Maer-enn-tri-poeng-drakt-ill.jpg 1x, /maer-enn-tri-poeng/_/image/eeea5b0e-1543-4892-812c-826ef5698f1c:5a6293904e37b60369673e84da8499aa9d9b7d05/wide-1680-944/Maer-enn-tri-poeng-drakt-ill.jpg 2x">
448								
449								<img src="/maer-enn-tri-poeng/_/image/eeea5b0e-1543-4892-812c-826ef5698f1c:5a6293904e37b60369673e84da8499aa9d9b7d05/wide-1160-652/Maer-enn-tri-poeng-drakt-ill.jpg">
450							</picture>
451						
452					</figure>
453				</div>
454			</div>
455			<div class="history__content">
456				<h2 class="heading heading--full">
457					<div class="heading__title">
458						<span class="heading__title__typo">Mær Enn Tri Poeng</span>
459					</div>
460				</h2>
461				<p class="history__leadin">
462					Fra 2024 samler klubben alle sine samfunns- og bærekraftsprosjekter under merkevaren «Mær enn tri poeng».
463					
464				</p>
465			</div>
466
467			
468
469
470
471		</a>
472	</div>
473
474<!-- HYPE-MODULE END -->
475
476
477            
478        
479        
480            <div data-portal-component-type="part" class="container">
481	<div class="article-list">
482		<h2 class="latest__news--title">VÅRE SAMFUNNSPROSJEKTER</h2>
483		<div class="news__grid o-no-margin-bottom">
484			<div class="grid__item grid__item-xs-12 grid__item-m-6">
485
486				<div>
487					<div
488						class="news"
489					>
490						<a class="news__link" href="https://www.fkh.no/maer-enn-tri-poeng/articles/gatelaget-24-copy">
491							<!-- Optional // -->
492							<div class="news__img" style="background-image:url(&#39;https://www.fkh.no/maer-enn-tri-poeng/_/image/083fff17-ce9c-4670-be82-02fd06c92606:f1188e19b9f8836c2e50c3b4ba04c6fc52a83632/block-800-450/Gatelaget.png.jpg&#39;);">
493								<div class="news__img__filter"></div>
494							</div>
495							
496							<!-- // Optional -->
497							<div class="news__content">
498								<div class="container container--static">
499									
500									<div class="news__heading">
501										<h3 class="news__heading__title">
502											<span class="news__heading__title__typo">GATELAGET</span>
503										</h3>
504									</div>
505								</div>
506							</div>
507						</a>
508					</div>
509				</div>
510
511			</div>
512			<div class="grid__item grid__item-xs-12 grid__item-m-6">
513
514				<div>
515					<div
516						class="news"
517					>
518						<a class="news__link" href="https://www.fkh.no/maer-enn-tri-poeng/articles/ung-jobb">
519							<!-- Optional // -->
520							
521							<div class="news__background"></div>
522							<!-- // Optional -->
523							<div class="news__content">
524								<div class="container container--static">
525									
526									<div class="news__heading">
527										<h3 class="news__heading__title">
528											<span class="news__heading__title__typo">Ung Jobb</span>
529										</h3>
530									</div>
531								</div>
532							</div>
533						</a>
534					</div>
535				</div>
536
537			</div>
538
539			<div class="grid__item grid__item-xs-10">
540				<div class="list list--partial ">
541					<ul class="list__list">
542						
543					</ul>
544
545				</div>
546			</div>
547		</div>
548
549		
550
551	</div>
552</div>
553
554
555            
556        
557        
558            <div data-portal-component-type="part" class="container">
559	<div class="article-list">
560		
561		<div class="news__grid o-no-margin-bottom">
562			
563
564			<div class="grid__item grid__item-xs-10">
565				<div class="list list--partial ">
566					<ul class="list__list">
567						<li class="list__item">
568							<a class="list__link" href="https://www.fkh.no/nyheter/klare-for-nasjonal-turnering">
569								Klare for Nasjonal Turnering
570								<div class="content-label__wrapper content-label__wrapper--vertical">
571									<div class="content-label">
572										Samfunnsprosjekter
573									</div>
574								</div>
575							</a>
576						</li>
577						<li class="list__item">
578							<a class="list__link" href="https://www.fkh.no/nyheter/styrke-og-samhold">
579								Styrke og samhold
580								<div class="content-label__wrapper content-label__wrapper--vertical">
581									<div class="content-label">
582										Samfunnsprosjekter
583									</div>
584								</div>
585							</a>
586						</li>
587						<li class="list__item">
588							<a class="list__link" href="https://www.fkh.no/nyheter/gatelagene-gir-677-millioner-i-samfunnsokonomisk-gevinst">
589								Gatelagene gir 677 millioner i samfunnsøkonomisk gevinst 
590								<div class="content-label__wrapper content-label__wrapper--vertical">
591									<div class="content-label">
592										Samfunnsprosjekter
593									</div>
594								</div>
595							</a>
596						</li>
597						<li class="list__item">
598							<a class="list__link" href="https://www.fkh.no/nyheter/fantastisk-gjeng-a-ha-med-seg-pa-tur">
599								- Fantastisk gjeng å ha med seg på tur
600								<div class="content-label__wrapper content-label__wrapper--vertical">
601									<div class="content-label">
602										Samfunnsprosjekter
603									</div>
604								</div>
605							</a>
606						</li>
607						<li class="list__item">
608							<a class="list__link" href="https://www.fkh.no/nyheter/klare-for-nasjonal-turnering-i-stavanger">
609								Klare for Nasjonal Turnering i Stavanger
610								<div class="content-label__wrapper content-label__wrapper--vertical">
611									<div class="content-label">
612										Samfunnsprosjekter
613									</div>
614								</div>
615							</a>
616						</li>
617						<li class="list__item">
618							<a class="list__link" href="https://www.fkh.no/nyheter/vi-skal-na-alle-jentespillerne-der-ute">
619								- Vi skal nå alle jentespillerne der ute
620								<div class="content-label__wrapper content-label__wrapper--vertical">
621									<div class="content-label">
622										Kraftakademiet
623									</div>
624									<div class="content-label">
625										Samfunnsprosjekter
626									</div>
627								</div>
628							</a>
629						</li>
630						<li class="list__item">
631							<a class="list__link" href="https://www.fkh.no/nyheter/motte-lovens-lange-arm">
632								Møtte Lovens Lange Arm
633								<div class="content-label__wrapper content-label__wrapper--vertical">
634									<div class="content-label">
635										Samfunnsprosjekter
636									</div>
637								</div>
638							</a>
639						</li>
640						<li class="list__item">
641							<a class="list__link" href="https://www.fkh.no/nyheter/fk-haugesund-soker-trener-til-kombinert-stilling-i-50">
642								FK Haugesund søker trener til kombinert stilling i 50%.
643								<div class="content-label__wrapper content-label__wrapper--vertical">
644									<div class="content-label">
645										Samfunnsprosjekter
646									</div>
647									<div class="content-label">
648										Kraftakademiet
649									</div>
650								</div>
651							</a>
652						</li>
653						<li class="list__item">
654							<a class="list__link" href="https://www.fkh.no/nyheter/638-millioner-i-samfunnsokonomisk-gevinst">
655								638 millioner i samfunnsøkonomisk gevinst
656								<div class="content-label__wrapper content-label__wrapper--vertical">
657									<div class="content-label">
658										Samfunnsprosjekter
659									</div>
660								</div>
661							</a>
662						</li>
663						<li class="list__item">
664							<a class="list__link" href="https://www.fkh.no/nyheter/lanserer-maer-enn-tri-poeng-alliansen">
665								Lanserer ‘Mær enn tri poeng’-alliansen
666								<div class="content-label__wrapper content-label__wrapper--vertical">
667									<div class="content-label">
668										Samfunnsprosjekter
669									</div>
670								</div>
671							</a>
672						</li>
673					</ul>
674
675				</div>
676			</div>
677		</div>
678
679		
680
681	</div>
682</div>
683
684
685            
686        
687    
688    
689</main>
690
691
692    <div class="navigationBarWrapper">
693	<div class="navigationBar">
694		<div class="navigationBar__items">
695			<div class="navigationBar__items--item">
696				<a class="icon" href="/">
697					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
698						<path d="M14.2495 14.25H9.74945V20.2493L3.75 20.2499V10.5L12 3L20.25 10.5V20.2499L14.2495 20.2493V14.25Z" stroke="white" stroke-width="1.5" stroke-linecap="round"/>
699					</svg>
700				</a>
701			</div>
702			<div class="navigationBar__items--item">
703				<button class="icon" data-itemNav="search">
704					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
705						<path d="M10.875 18.75C15.2242 18.75 18.75 15.2242 18.75 10.875C18.75 6.52576 15.2242 3 10.875 3C6.52576 3 3 6.52576 3 10.875C3 15.2242 6.52576 18.75 10.875 18.75Z" stroke="white" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
706						<path d="M16.4431 16.4438L20.9994 21.0001" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
707					</svg>
708				</button>
709			</div>
710			<div class="navigationBar__items--item">
711				<a class="icon" href="https://fantasy.eliteserien.no/" target="_blank">
712					<img src="/_/image/75ed9b65-fe51-452f-98dd-0fbf7ae679e6:878e2f24267c8241a69c9a8befcec7826344136a/block-24-24/fantasy-logo_64.svg" />
713				</a>
714			</div>
715			<div class="navigationBar__items--item" hidden>
716				<button class="icon" data-itemNav="user">
717					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
718						<path d="M12 15C15.3137 15 18 12.3137 18 9C18 5.68629 15.3137 3 12 3C8.68629 3 6 5.68629 6 9C6 12.3137 8.68629 15 12 15Z" stroke="white" stroke-width="1.5" stroke-miterlimit="10"/>
719						<path d="M2.90527 20.2491C3.82736 18.6531 5.15322 17.3278 6.74966 16.4064C8.34611 15.485 10.1569 15 12.0002 15C13.8434 15 15.6542 15.4851 17.2506 16.4065C18.8471 17.3279 20.1729 18.6533 21.0949 20.2493" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
720					</svg>
721				</button>
722			</div>
723			<div class="navigationBar__items--item">
724				<button class="icon" data-itemNav="menu">
725					<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
726						<path d="M3.75 12H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
727						<path d="M3.75 6H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
728						<path d="M3.75 18H20.25" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
729					</svg>
730				</button>
731			</div>
732		</div>
733	</div>
734</div>
735
736<div class="navigationContentWrapper" data-itemNav="search" aria-expanded="false">
737
738	<div class="navigationArea"></div>
739	<div class="navigationBtnSwipe"></div>
740
741	<div class="navigationContent">
742
743		<div class="inputSearch">
744            <form action="https://www.fkh.no/sok" method="get">
745                <input type="text" name="text" id="sok-mobile-input" maxlength="128">
746                
747                <button aria-label="Søk">
748                    <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" aria-hidden="true">
749                        <path d="M10.875 18.75C15.2242 18.75 18.75 15.2242 18.75 10.875C18.75 6.52576 15.2242 3 10.875 3C6.52576 3 3 6.52576 3 10.875C3 15.2242 6.52576 18.75 10.875 18.75Z" stroke="white" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"/>
750                        <path d="M16.4431 16.4438L20.9994 21.0001" stroke="white" stroke-width="1.5" stroke-linecap="square" stroke-linejoin="round"/>
751                    </svg>
752                </button>
753            </form>
754        </div>
755
756		<div class="popularSearch">
757			<h3>Populære søk</h3>
758			<div class="popularSearch__list">
759				
760			</div>
761		</div>
762
763	</div>
764</div>
765
766<div class="navigationContentWrapper" data-itemNav="user" aria-expanded="false" data-service-url="/_/service/no.seeds.app.football/get-idrettens-detail
766s">
767
768    <div class="navigationArea"></div>
769	<div class="navigationBtnSwipe"></div>
770
771	<div class="navigationContent">
772		<div class="ui loader"></div>
773		<div class="loginTab loginButton" hidden>
774			<div class="loginTab__header--content">
775				<p id="loginMessage" class="login-description"></p>
776				<a class="modal-open" href="javascript:void(0)"></a>
777			</div>
778		</div>
779        <div class="loginTab userDetails" hidden>
780            <div class="navigationButtons">
781                <a href="https://www.fkh.no/minside" class="button active">PROFIL</a>
782                <a href="https://www.fkh.no/minside?ticket=true" class="button">BILLETTER</a>
783                <a href="https://www.fkh.no/minside?edit=true" class="button">REDIGER PROFIL</a>
784             </div>
785            <div class="loginTab__header">
786                <div class="loginTab__header--image">
787					<div class="ntfpwa__default__profile__small"></div>
788                </div>
789                <div class="loginTab__header--content">
790                    <span name="completename"></span>
791                </div>
792				<div class="loginTab__header--notification renew-push-notifications" style="display: none;">
793					<svg stroke="white" width="32px" height="64px" viewBox="0 0 611.999 611.999" fill="none" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
794						<title id="renewPushTitle"></title>
795						<path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
796							C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
797							c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
798							h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
799							c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
800							C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
801							c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
802							c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
803							M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
804							c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
805							c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"></path>
806						<path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
807							c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
808							C323.259,126.96,315.532,119.235,306.001,119.235z"></path>
809					</svg>
810					<div class="notification-loading">
811						<img src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/img/loading.gif" />
812					</div>
813				</div>
814            </div>
815
816            <div class="loginTab__content">
817                <dl class="loginTab__content--info">
818					<dt>EPost</dt>
819                    <dd name="email"></dd>
820					<dt>Mobilnummer</dt>
821					<dd name="phone"></dd>
822					<dt>Fødselsdato</dt>
823					<dd name="birthdate"></dd>
824					<dt>Adresse</dt>
825					<dd name="address"></dd>
826					<dt>Postnr.</dt>
827					<dd name="zipcode"></dd>
828					<dt>Poststed</dt>
829					<dd name="city"></dd>
830					<dt>Kjønn</dt>
831					<dd name="sex"></dd>
832                </dl>
833
834                <h4>Pushmeldinger</h4>
835
836                <dl class="loginTab__content--options notification-tab">
837                    <dt>Generelle varslinger</dt>
838                    <dd name="general-alert">
839                        <div class="switch__container">
840                            <input id="notification-general-alert-from-bottom" data-id="notification-general-alert" class="switch switch--shadow" type="checkbox" disabled />
841                            <label for="notification-general-alert-from-bottom"></label>
842                        </div>
843                    </dd>
844                    <dt>Varsling ved publisering av nyheter</dt>
845                    <dd name="news">
846                        <div class="switch__container">
847                            <input id="notification-news-from-bottom" data-id="notification-news" class="switch switch--shadow" type="checkbox" disabled />
848                            <label for="notification-news-from-bottom"></label>
849                        </div>
850                    </dd>
851                    <dt>Kamphendelser</dt>
852                    <dd name="match">
853                        <div class="switch__container">
854                            <input id="notification-match-from-bottom" data-id="notification-match" class="switch switch--shadow" type="checkbox" disabled />
855                            <label for="notification-match-from-bottom"></label>
856                        </div>
857                    </dd>
858                </dl>
859
860                <h4>Kommunikasjon og Samtykker</h4>
861
862                <dl class="loginTab__content--options">
863					
864						<dt>SMS</dt>
865						<dd name="1001">
866							<div class="switch__container">
867								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
868								<label for="switch-shadow"></label>
869							</div>
870						</dd>
871					
872						<dt>Epost</dt>
873						<dd name="1002">
874							<div class="switch__container">
875								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
876								<label for="switch-shadow"></label>
877							</div>
878						</dd>
879					
880						<dt>Kommunikasjon fra våre partnere</dt>
881						<dd name="1004">
882							<div class="switch__container">
883								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
884								<label for="switch-shadow"></label>
885							</div>
886						</dd>
887					
888						<dt>Kommunikasjon fra OBOS-ligaen og Eliteserien</dt>
889						<dd name="1005">
890							<div class="switch__container">
891								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
892								<label for="switch-shadow"></label>
893							</div>
894						</dd>
895					
896						<dt>Kommunikasjon fra rettighetshaver</dt>
897						<dd name="1006">
898							<div class="switch__container">
899								<input id="switch-shadow" class="switch switch--shadow" type="checkbox" disabled />
900								<label for="switch-shadow"></label>
901							</div>
902						</dd>
903					
904                </dl>
905            </div>
906			<div class="navigationButtons">
907                <a href="" class="button">REDIGER SAMTYKKER</a>
908             </div>
909        </div>
910	</div>
911</div>
912
913<div class="navigationContentWrapper" data-itemNav="menu" aria-expanded="false">
914
915    <div class="navigationArea"></div>
916	<div class="navigationBtnSwipe"></div>
917
918	<div class="navigationContent">
919		
920
921		<div class="groupLink">
922			<a class="item" href="https://www.fkh.no/nyheter">
923                Nyheter
924                
925				
926				
927				
928            </a><a class="item" href="https://www.fkh.no/lag">
929                Lagene
930                
931				
932				
933				
934            </a>
934<a class="item" href="https://www.fkh.no/terminliste">
935                Terminliste
936                
937				
938				
939				
940            </a><a class="item" href="https://www.fkh.no/resultater">
941                Resultater
942                
943				
944				
945				
946            </a><a class="item" href="https://www.fkh.no/billetter" target="_blank">
947                Billetter &amp; Sesongkort
948                <span>
949					<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
950						<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
951					</svg>
952				</span>
953				
954				
955				
956            </a><a class="item" href="https://www.fkh.no/nyheter/fkh-akademiet/kraftakademiet" target="_blank">
957                Kraftakademiet
958                <span>
959					<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
960						<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
961					</svg>
962				</span>
963				
964				
965				
966            </a><a class="item" href="https://www.fkh.no/om-klubben">
967                Om Klubben
968                
969				
970				
971				
972            </a>
973		</div>
974
975		<div class="groupLink">
976			
977				<a class="item" href="https://www.fkh.no/nyheter/presseakkreditering" target="_blank">
978					Presse
979					<span>
980						<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
981							<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
982						</svg>
983					</span>
984				</a>
985			
986				<a class="item" href="https://www.fkh.no/maer-enn-tri-poeng">
987					Mær Enn Tri Poeng
988					
989				</a>
990			
991				<a class="item" href="https://www.fkh.no/samarbeidspartnere" target="_blank">
992					Partnere
993					<span>
994						<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
995							<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
996						</svg>
997					</span>
998				</a>
999			
1000				<a class="item" href="https://www.fkh.no/nettbutikk" target="_blank">
1001					Nettbutikk
1002					<span>
1003						<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
1004							<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
1005						</svg>
1006					</span>
1007				</a>
1008			
1009				<a class="item" href="https://www.fkh.no/nyheter/jenteloftet" target="_blank">
1010					Jenteløftet
1011					<span>
1012						<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
1013							<path fill-rule="evenodd" clip-rule="evenodd" d="M4.25011 0.209961H3.50011V1.70996H4.25011H12.1895L1.46978 12.4296L0.939453 12.96L2.00011 14.0206L2.53044 13.4903L13.2501 2.77062V10.71V11.46H14.7501V10.71V0.959961V0.209961H14.0001H4.25011Z" fill="#B4975A"/>
1014						</svg>
1015					</span>
1016				</a>
1017			
1018				<a class="item" href="https://www.fkh.no/medlem">
1019					Bli medlem
1020					
1021				</a>
1022			
1023				<a class="item" href="https://www.fkh.no/feature/kraftakademiet-ffo">
1024					Fotballfritidsordning (FFO)
1025					
1026				</a>
1027			
1028		</div>
1029
1030		<div class="groupLink">
1031			<a class="item open-push-notification-modal" href="javascript:void(0)" style="display: none;">
1032				PUSH-VARSLINGER
1033				<span>
1034					<svg stroke="white" width="24px" height="20px" viewBox="0 0 611.999 611.999" fill="#010101" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
1035                        <title id="renewPushTitle"></title>
1036                        <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
1037                            C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
1038                            c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
1039                            h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
1040                            c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
1041                            C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
1042                            c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
1043                            c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
1044                            M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
1045                            c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
1046                            c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"/>
1047                        <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
1048                            c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
1049                            C323.259,126.96,315.532,119.235,306.001,119.235z"/>
1050                    </svg>
1051				</span>
1052			</a>
1053		</div>
1054	</div>
1055
1056</div>
1057
1058
1059    <footer class="footer">
1060	<div class="footer__bar">
1061		<a class="footer__bar__brand" href="/" >
1062			<img class="footer__bar__brand__img" src="https://www.fkh.no/maer-enn-tri-poeng/_/image/dff142f0-041c-49cd-bac2-f5311254efa0:6064425925da495c54dfee7cbbcde8defc3b9897/wide-72-72/Logo%20550%202.svg" alt="Klubb"/>
1063		</a>
1064	</div>
1065	<div class="footer__content">
1066		<div class="container">
1067			<p>
1068			<span class="footer__contact">
1069				<span>E-post</span>:
1070				<a href="/cdn-cgi/l/email-protection#6b060e0f020a2b0d0003450504"><span class="__cf_email__" data-cfemail="39545c5d5058795f5251175756">[email&#160;protected]</span></a>
1071			</span>
1072			<span class="footer__contact">
1073				<span>Telefon</span>:
1074				<a href="tel:+47 41 00 00 55">+47 41 00 00 55</a>
1075			</span>
1076			
1077			<span class="footer__contact">
1078				<a href="https://www.fkh.no/om-klubben">Kontakt oss</a>
1079			</span>
1080			</p>
1081			<div class="o-space-grid-gutter"></div>
1082			<p>
1083			<span class="footer__contact">
1084				<a target="_blank" class="link link--with-icon" href="https://www.facebook.com/fkhaugesund/">
1085					<span class="link__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
1086<g>
1087	<path d="M12,0C5.3725586,0,0,5.3725586,0,12s5.3725586,12,12,12s12-5.3725586,12-12S18.6274414,0,12,0z M14.5249634,12.3076782
1088		h-1.6512451c0,2.6392212,0,5.8892212,0,5.8892212h-2.4484863c0,0,0-3.2174683,0-5.8892212H9.2615356v-2.0810547h1.1636963
1089		V8.8809204c0-0.9638672,0.4581909-2.4708252,2.4697266-2.4708252l1.8133545,0.0076294V8.437439c0,0-1.1022949,0-1.3163452,0
1090		c-0.2142944,0-0.5182495,0.1066895-0.5182495,0.5664673v1.2227173h1.8647461L14.5249634,12.3076782z"></path>
1091</g>
1092</svg></span>
1093					Facebook
1094				</a>
1095			</span><span class="footer__contact">
1096				<a target="_blank" class="link link--with-icon" href="https://www.instagram.com/fk_haugesund/">
1097					<span class="link__icon"><svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="24px" height="24px" viewBox="0 0 24 24" style="enable-background:new 0 0 24 24;" xml:space="preserve">
1098<g>
1099	<path d="M17.5010376,7.8382568c-0.1280518-0.3294067-0.2809448-0.5644531-0.5278931-0.8114014
1100		s-0.4819946-0.3998413-0.8113403-0.5278931c-0.2486572-0.0966187-0.6223145-0.2115479-1.3103638-0.242981
1101		C14.1073608,6.2220459,13.8842163,6.2148438,12,6.2148438S9.8926392,6.2220459,9.1484985,6.2559814
1102		C8.4605103,6.2874146,8.086853,6.4023438,7.8382568,6.4989624C7.5088501,6.6270142,7.2738037,6.7799072,7.0268555,7.0268555
1103		S6.6270142,7.5088501,6.4989624,7.8382568C6.4023438,8.086853,6.2874146,8.4605103,6.2559814,9.1485596
1104		C6.2220459,9.8926392,6.2148438,10.1157837,6.2148438,12s0.0072021,2.1073608,0.0411377,2.8515015
1105		c0.0314331,0.6879883,0.1463623,1.0616455,0.242981,1.3103027c0.1280518,0.3293457,0.2809448,0.5644531,0.5278931,0.8113403
1106		c0.2469482,0.2469482,0.4819946,0.3998413,0.8114014,0.5278931c0.2485962,0.0966187,0.6222534,0.2115479,1.3103027,0.242981
1107		C9.8925171,17.7779541,10.1156616,17.7851562,12,17.7851562s2.1074829-0.0072021,2.8514404-0.0411377
1108		c0.6880493-0.0314331,1.0617065-0.1463623,1.3103638-0.242981c0.3293457-0.1280518,0.5643921-0.2809448,0.8113403-0.5278931
1109		s0.3998413-0.4819946,0.5278931-0.8113403c0.0966187-0.2486572,0.2115479-0.6223145,0.242981-1.3103638
1110		C17.7779541,14.1073608,17.7851562,13.8842163,17.7851562,12s-0.0072021-2.1073608-0.0411377-2.8515015
1111		C17.7125854,8.4605103,17.5976562,8.086853,17.5010376,7.8382568z M12,15.6236572
1112		c-2.0012817,0-3.6236572-1.6223755-3.6236572-3.6236572S9.9987183,8.3763428,12,8.3763428S15.6236572,9.9987183,15.6236572,12
1113		S14.0012817,15.6236572,12,15.6236572z M15.7668457,9.0799561c-0.4677124,0-0.8468018-0.3790894-0.8468018-0.8468018
1114		c0-0.4676514,0.3790894-0.8467407,0.8468018-0.8467407c0.4676514,0,0.8467407,0.3790894,0.8467407,0.8467407
1115		C16.6135864,8.7008667,16.2344971,9.0799561,15.7668457,9.0799561z"></path>
1116	<circle cx="12" cy="12" r="2.3521729"></circle>
1117	<path d="M12,0C5.3725586,0,0,5.3725586,0,12s5.3725586,12,12,12s12-5.3725586,12-12S18.6274414,0,12,0z M19.0140991,14.9094238
1118		c-0.0342407,0.7510986-0.1535034,1.2640381-0.3280029,1.7128906c-0.1802979,0.4640503-0.4215698,0.857605-0.8139038,1.2498779
1119		c-0.3922729,0.392334-0.7858276,0.633606-1.2498779,0.8139038c-0.4488525,0.1744995-0.961792,0.2937622-1.7128906,0.3280029
1120		C14.1567383,19.0484619,13.9164429,19.0565796,12,19.0565796s-2.1567383-0.0081177-2.9094238-0.0424805
1121		c-0.7510986-0.0342407-1.2640381-0.1535034-1.7128906-0.3280029c-0.4640503-0.1802979-0.857605-0.4215698-1.2498779-0.8139038
1122		c-0.392334-0.3922729-0.633606-0.7858276-0.8139038-1.2498779c-0.1744995-0.4488525-0.2937622-0.961792-0.328064-1.7128906
1123		C4.9515381,14.1567383,4.9434204,13.9164429,4.9434204,12s0.0081177-2.1567383,0.0424194-2.9094238
1124		c0.0343018-0.7510986,0.1535645-1.2640381,0.328064-1.7128906c0.1802979-0.4640503,0.4215698-0.857605,0.8139038-1.2498779
1125		c0.3922729-0.392334,0.7858276-0.633606,1.2498779-0.8139038c0.4488525-0.1744995,0.961792-0.2937622,1.7128906-0.328064
1126		C9.8432617,4.9515381,10.0835571,4.9434204,12,4.9434204s2.1567383,0.0081177,2.9094238,0.0424194
1127		c0.7510986,0.0343018,1.2640381,0.1535645,1.7128906,0.328064c0.4640503,0.1802979,0.857605,0.4215698,1.2498779,0.8139038
1128		c0.392334,0.3922729,0.633606,0.7858276,0.8139038,1.2498779c0.1744995,0.4488525,0.2937622,0.961792,0.3280029,1.7128906
1129		C19.0484619,9.8432617,19.0565796,10.0835571,19.0565796,12S19.0484619,14.1567383,19.0140991,14.9094238z"></path>
1130</g>
1131</svg></span>
1132					Instagram
1133				</a>
1134			</span><span class="footer__contact">
1135				<a target="_blank" class="link link--with-icon" href="https://twitter.com/fkhaugesund?lang=no">
1136					<span class="link__icon"><svg version="1.1" id="svg5" xmlns:svg="http://www.w3.org/2000/svg"
1137	 xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 1668.56 1221.19"
1138	 style="enable-background:new 0 0 1668.56 1221.19;" xml:space="preserve">
1139<circle cx="834.28" cy="610.595" r="800" fill="white"/>
1140<g id="layer1" transform="translate(52.390088,-25.058597)">
1141	<path id="path1009" d="M283.94,167.31l386.39,516.64L281.5,1104h87.51l340.42-367.76L984.48,1104h297.8L874.15,558.3l361.92-390.99
1142		h-87.51l-313.51,338.7l-253.31-338.7H283.94z M412.63,231.77h136.81l604.13,807.76h-136.81L412.63,231.77z" fill="black"/>
1143</g>
1144</svg>
1145</span>
1146					Twitter
1147				</a>
1148			</span>
1149			</p>
1150			<div class="o-space-gutter-3"></div>
1151			<form class="newsletter ng-pristine ng-scope ng-valid-email ng-invalid ng-invalid-required" data-ng-controller="newsletter" name="formNewsletter" data-custom-submit="submitForm(input)" novalidate="novalidate">
1152				<div data-ng-hide="formNewsletter.formNewsletterEmail.$valid &amp;&amp; !formNewsletter.formNewsletterEmail.$errors &amp;&amp; submitted">
1153					<label class="label" for="formNewsletterEmail">Abonner på nyhetsbrev fra fkh</label>
1154					<div class="newsletter__input">
1155						<div class="form__block">
1156							<input class="input ng-pristine ng-untouched ng-empty ng-valid-email ng-invalid ng-invalid-required" name="formNewsletterEmail" id="formNewsletterEmail" aria-describedby="formNewsletterEmailError" type="email" value="" data-ng-model="input.formNewsletterEmailValidation" required="" placeholder="E-postadresse" />
1157							<!-- ngIf: formNewsletter.formNewsletterEmail.$invalid && submitted -->
1158						</div>
1159					</div>
1160					<div class="newsletter__submit">
1161						<button class="button button--full" type="submit">PÃ¥melding</button>
1162					</div>
1163				</div>
1164				<div class="newsletter__success ng-hide" data-ng-show="formNewsletter.formNewsletterEmail.$valid &amp;&amp; !formNewsletter.formNewsletterEmail.$errors &amp;&amp; submitted">
1165					<div class="box" ng-cloak="">
1166						<p ng-bind="newsletterResponse" class="o-color-fkh-safe-dark">
1167							Takk for din påmelding!
1168						</p>
1169					</div>
1170				</div>
1171			</form>
1172			<p>Redaktør: Runar Nordvik</p>
1173
1174			<p>
1175				<a href="https://www.eliteserien.no/vilkar-og-betingelser" target="_blank">Vilkår og betingelser</a>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="https://www.eliteserien.no/personvern" target="_blank">Personvern</a>
1176			</p>
1177		</div>
1178	</div>
1179</footer>
1180
1181
1182
1183<div class="modal-login">
1184    <a href="javascript:void(0)" title="Close" class="modal-login__close">X</a>
1185    <div class="modal-login__title">
1186        <h2>Innlogging på Haugesund</h2>
1187    </div>
1188    <div class="modal-login__content">
1189        <p><p>PÃ¥ denne nettsiden benyttes Idrettens ID til innlogging. Idrettens ID er en enkel og trygg innlogging utviklet av Norges idrettsforbund og Buypass. Les mer om Idrettens ID hos <a href="https://www.idrettsforbundet.no/digital/idrettens-id/">Norges Idrettsforbund</a></p>
1190
1191<h2>Jeg har bruker</h2>
1192
1193<p>Hvis du allerede har en bruker: <a href="/_/idprovider/idrettensid/login?idProvider=idrettensid">logg inn her</a></p>
1194
1195<h2>Jeg må lage ny bruker</h2>
1196
1197<p>Ny bruker kan du lage <a href="https://signup.nif.no/" target="_blank">her</a></p>
1198
1199<p><strong>PS: </strong>Hvis du er usikker på om du har en bruker kan du finne ut av det <a href="https://www.nif.buypass.no/nif-forgot-password/">hos Norges idrettsforbund.</a></p>
1200</p>
1201    </div>
1202</div>
1203
1204<div class="modal-notification">
1205    <a href="javascript:void(0)" title="Close" class="modal-notification__close">X</a>
1206    <div class="modal-notification__title">
1207        <h2>Header</h2>
1208    </div>
1209    <div class="modal-notification__content">
1210        <p>Content</p>
1211    </div>
1212</div>
1213
1214<div class="modal-notification-switch">
1215    <a href="javascript:void(0)" title="Close" class="modal-notification-switch__close">X</a>
1216    <div class="modal-notification-switch__title">
1217        <h2>
1218            <svg stroke="#010101" width="24px" height="24px" viewBox="0 0 611.999 611.999" fill="#010101" xmlns="http://www.w3.org/2000/svg" aria-labelledby="renewPushTitle">
1219                <title id="renewPushTitle"></title>
1220                <path d="M570.107,500.254c-65.037-29.371-67.511-155.441-67.559-158.622v-84.578c0-81.402-49.742-151.399-120.427-181.203
1221                    C381.969,34,347.883,0,306.001,0c-41.883,0-75.968,34.002-76.121,75.849c-70.682,29.804-120.425,99.801-120.425,181.203v84.578
1222                    c-0.046,3.181-2.522,129.251-67.561,158.622c-7.409,3.347-11.481,11.412-9.768,19.36c1.711,7.949,8.74,13.626,16.871,13.626
1223                    h164.88c3.38,18.594,12.172,35.892,25.619,49.903c17.86,18.608,41.479,28.856,66.502,28.856
1224                    c25.025,0,48.644-10.248,66.502-28.856c13.449-14.012,22.241-31.311,25.619-49.903h164.88c8.131,0,15.159-5.676,16.872-13.626
1225                    C581.586,511.664,577.516,503.6,570.107,500.254z M484.434,439.859c6.837,20.728,16.518,41.544,30.246,58.866H97.32
1226                    c13.726-17.32,23.407-38.135,30.244-58.866H484.434z M306.001,34.515c18.945,0,34.963,12.73,39.975,30.082
1227                    c-12.912-2.678-26.282-4.09-39.975-4.09s-27.063,1.411-39.975,4.09C271.039,47.246,287.057,34.515,306.001,34.515z
1228                    M143.97,341.736v-84.685c0-89.343,72.686-162.029,162.031-162.029s162.031,72.686,162.031,162.029v84.826
1229                    c0.023,2.596,0.427,29.879,7.303,63.465H136.663C143.543,371.724,143.949,344.393,143.97,341.736z M306.001,577.485
1230                    c-26.341,0-49.33-18.992-56.709-44.246h113.416C355.329,558.493,332.344,577.485,306.001,577.485z"></path>
1231                <path d="M306.001,119.235c-74.25,0-134.657,60.405-134.657,134.654c0,9.531,7.727,17.258,17.258,17.258
1232                    c9.531,0,17.258-7.727,17.258-17.258c0-55.217,44.923-100.139,100.142-100.139c9.531,0,17.258-7.727,17.258-17.258
1233                    C323.259,126.96,315.532,119.235,306.001,119.235z"></path>
1234            </svg>
1235            <span>Header</span>
1236        </h2>
1237    </div>
1238    <div class="modal-notification-switch__content">
1239        <p>Content</p>
1240    </div>
1241    <div class="switch__container">
1242        <input id="modal-notification-switch" class="switch switch--shadow" type="checkbox" />
1243        <label for="modal-notification-switch"></label>
1244        <div class="modal-notification-loading">
1245            <img src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/img/loading.gif" />
1246        </div>
1247    </div>
1248</div>
vendor: 110 bytes, lines 1248-1250
1248
1249
1250<script data-cfasync="false" src="/cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script>
1250<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/compiled/js/app.bundle.js"></script>
vendor: 1 bytes, line 1250
1250
1251<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/js/blazy.js" defer></script>
vendor: 1 bytes, line 1251
1251
1252<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/js/navigation-bar.js"></script>
vendor: 1 bytes, line 1252
1252
1253<script type="text/javascript" src="/_/service/no.seeds.app.football/asset/0000019ff1669df0/js/embed-league-table.js"></script>
1253
1254
1255
1256
1257
1258
1259<script type="text/javascript" src="/_/asset/ntfpwa:0000019dab7c0930/bundles/js/sw/register.js"></script>
vendor: 1 bytes, line 1259
1259
1260<script type="text/javascript">
1261    Starter.registerServiceWorker('https://www.fkh.no/')
1262</script>
1262
1263<!-- Firebase SW -->
1264<script src="https://www.gstatic.com/firebasejs/10.9.0/firebase-app-compat.js"></script>
vendor: 1 bytes, line 1264
1264
1265<script src="https://www.gstatic.com/firebasejs/10.9.0/firebase-messaging-compat.js"></script>
vendor: 1 bytes, line 1265
1265
1266<script type="text/javascript" src="/_/asset/ntfpwa:0000019dab7c0930/bundles/js/push-notification.js" data-service-connect-url="https://www.fkh.no/maer-enn-tri-poeng/_/service/no.seeds.app.football/push-notification-connect" data-service-manage-notifications-url="https://www.fkh.no/maer-enn-tri-poeng/_/service/no.seeds.app.football/push-notification-manage" data-api-key="AIzaSyBG6ZX1FtMCafepTSIgPa46BT35hUqTg3w" data-auth-domain="ntf-pwa.firebaseapp.com" data-project-id="ntf-pwa" data-storage-bucket="ntf-pwa.appspot.com" data-messaging-sender-id="153894812237" data-app-id="1:153894812237:web:e2034b52443c51136c7a04" data-vapid-key="BIjKkVgFdPrJ1KnET80h3CeKFJnOPk9QiQo8qZli_fiQUa1WFqn9va9QgTKZeybEr_d6GA3uxqYnRmwlHkpi7dU" data-icon-url="/_/service/no.seeds.app.football/asset/0000019ff1669df0/img/logo/fkh/android-icon-512x512.png" data-email-domain="fkh.no" data-is-loged="false">
1267</script>
1267
1268<!-- Firebase SW end -->
1269
1270<script>
1271    var isAlreadyLoggedIdrettens = localStorage.getItem('isAlreadyLoggedIdrettens') || false;
1272    if (isAlreadyLoggedIdrettens) {
1273        localStorage.setItem('isAlreadyLoggedIdrettens', true);
1274    }
1275</script>
1275
1276
1277<script type="module" src="https://static.cloudflareinsights.com/beacon.min.js/v31edd6df95cf4e85bb4c19e7a9bdbcba1788362987495" integrity="sha512-iIg7k2xntmwu6/uSb5tpc/hySgZc4eoL31yB29W6tJFo2akwjPWcEqnCEdJvGexCL0KEQwVYv5BlowfhVz26hg==" data-cf-beacon='{"version":"2024.11.0","token":"1166188ffd5f458d89fd2b1e153d345a","r":1,"spa":2}' crossorigin="anonymous"></script>
1277
1278</body>
1279</html>

Line numbers count LF bytes from the start of the resource, as the search results do. Vendor segments are library code the classifier recognised; they are stored but not indexed. Bytes are shown as Latin1 characters, one per byte.